@@ -3,13 +3,13 @@
 #'   initialized site_models objects
 #' @return TRUE if x, or all elements of x, are initialized site_model objects
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 are_init_site_models <- function(
   x
 ) {
-  if (!are_site_models(x)) return(FALSE) # nolint beautier function
+  if (!beautier::are_site_models(x)) return(FALSE)
   for (i in x) {
-    if (!is_init_site_model(i)) return(FALSE) # nolint beautier function call
+    if (!beautier::is_init_site_model(i)) return(FALSE)
   }
   return(TRUE)
 }
