@@ -1,5 +1,8 @@
 #' Creates the '\code{run}' section of a BEAST2 XML parameter file
 #'
+#' Creates the '\code{run}' section of a BEAST2 XML parameter file,
+#' without being indented.
+#'
 #' The \code{run} tag has these elements:
 #' \preformatted{
 #'    <run[...]>
@@ -36,52 +39,43 @@ create_beast2_input_run <- function(
   input_filename,
   inference_model = create_inference_model()
 ) {
-  testit::assert(length(input_filename) == 1)
-
-  # Alignment IDs
-  ids <- beautier::get_alignment_id(
-    input_filename,
-    capitalize_first_char_id =
-      inference_model$beauti_options$capitalize_first_char_id
-  )
+  testthat::expect_equal(length(input_filename), 1)
 
   # Do not be smart yet
   site_models <- list(inference_model$site_model)
   clock_models <- list(inference_model$clock_model)
   tree_priors <- list(inference_model$tree_prior)
   mrca_priors <- list(inference_model$mrca_prior)
-  mcmc <- inference_model$mcmc
-  fixed_crown_ages <- FALSE
   tipdates_filename <- inference_model$tipdates_filename
 
-  text <- beautier::mcmc_to_xml_run(mcmc)
+  # Create the '<run...' starting tag
+  text <- beautier::mcmc_to_xml_run(inference_model$mcmc)
+  if (inference_model$beauti_options$beast2_version == "2.6") {
+    text <- c(text, "        ")
+  }
+
+  # Create the '<state...' part
   text <- c(text,
     beautier::indent(
       beautier::create_beast2_input_state(
-        site_models = site_models,
-        clock_models = clock_models,
-        tree_priors = tree_priors,
-        mrca_priors = mrca_priors,
-        tipdates_filename = tipdates_filename
+        inference_model = inference_model
       )
     )
   )
 
   text <- c(text,
     create_beast2_input_init(
-      ids = ids
+      inference_model = inference_model
     )
   )
 
   text <- c(text, "")
 
   text <- c(text,
-    create_beast2_input_distr(
-      site_models = site_models,
-      clock_models = clock_models,
-      tree_priors = tree_priors,
-      mrca_priors = mrca_priors,
-      tipdates_filename = tipdates_filename
+    beautier::indent(
+      beautier::create_beast2_input_distr(
+        inference_model = inference_model
+      )
     )
   )
 
@@ -93,7 +87,7 @@ create_beast2_input_run <- function(
       site_models = site_models,
       clock_models = clock_models,
       tree_priors = tree_priors,
-      fixed_crown_ages = fixed_crown_ages,
+      fixed_crown_ages = FALSE,
       mrca_priors = mrca_priors,
       tipdates_filename = tipdates_filename
     )
