@@ -3,35 +3,35 @@
 #' @param section the XML section name
 #' @return the section's lines of XML text, including the tags
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 extract_xml_section_from_lines <- function(
   lines,
   section
 ) {
   assertive::assert_is_a_string(section)
   if (section == "operators") {
-    return(extract_xml_operators_from_lines(lines)) # nolint beautier function
+    return(beautier::extract_xml_operators_from_lines(lines))
   }
   if (section == "loggers") {
     return(beautier::extract_xml_loggers_from_lines(lines))
   }
-  if (!has_xml_opening_tag(lines = lines, section = section)) { # nolint beautier function
+  if (!beautier::has_xml_opening_tag(lines = lines, section = section)) {
     stop(
       "Opening tag for 'section' could not be found in 'lines', ",
       "'section' has value '", section, "'"
     )
   }
-  if (!has_xml_closing_tag(lines = lines, section = section)) { # nolint beautier function
+  if (!beautier::has_xml_closing_tag(lines = lines, section = section)) {
     stop(
       "Closing tag for 'section' could not be found in 'lines', ",
       "'section' has value '", section, "'"
     )
   }
-  from_index <- find_first_xml_opening_tag_line( # nolint beautier function
+  from_index <- beautier::find_first_xml_opening_tag_line(
     lines = lines,
     section = section
   )
-  to_index <- find_last_xml_closing_tag_line( # nolint beautier function
+  to_index <- beautier::find_last_xml_closing_tag_line(
     lines = lines,
     section = section
   )
