@@ -3,22 +3,22 @@
 #'   initialized tree_priors object
 #' @return TRUE if x is an initialized tree_prior object
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 is_init_tree_prior <- function(
   x
 ) {
-  if (!is_tree_prior(x)) return(FALSE) # nolint beautier function
-  if (is_bd_tree_prior(x)) { # nolint beautier function
-    return(is_init_bd_tree_prior(x))  # nolint beautier function call
-  } else if (is_cbs_tree_prior(x)) { # nolint beautier function
-    return(is_init_cbs_tree_prior(x))  # nolint beautier function call
-  } else if (is_ccp_tree_prior(x)) { # nolint beautier function
-    return(is_init_ccp_tree_prior(x))  # nolint beautier function call
-  } else if (is_cep_tree_prior(x)) { # nolint beautier function
-    return(is_init_cep_tree_prior(x))  # nolint beautier function call
+  if (!beautier::is_tree_prior(x)) return(FALSE)
+  if (beautier::is_bd_tree_prior(x)) {
+    return(beautier::is_init_bd_tree_prior(x))
+  } else if (beautier::is_cbs_tree_prior(x)) {
+    return(beautier::is_init_cbs_tree_prior(x))
+  } else if (beautier::is_ccp_tree_prior(x)) {
+    return(beautier::is_init_ccp_tree_prior(x))
+  } else if (beautier::is_cep_tree_prior(x)) {
+    return(beautier::is_init_cep_tree_prior(x))
   } else {
-    testit::assert(is_yule_tree_prior(x)) # nolint beautier function
-    return(is_init_yule_tree_prior(x))  # nolint beautier function call
+    testit::assert(beautier::is_yule_tree_prior(x))
+    return(beautier::is_init_yule_tree_prior(x))
   }
 }
 
@@ -27,13 +27,13 @@ is_init_tree_prior <- function(
 #'   initialized Birth-Death tree prior object
 #' @return TRUE if x is an initialized Birth-Death tree_prior object
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 is_init_bd_tree_prior <- function(
   x
 ) {
-  testit::assert(is_bd_tree_prior(x)) # nolint beautier function
-  is_init_distr(x$birth_rate_distr) && # nolint beautier function
-    is_init_distr(x$death_rate_distr) # nolint beautier function
+  testit::assert(beautier::is_bd_tree_prior(x))
+  beautier::is_init_distr(x$birth_rate_distr) &&
+    beautier::is_init_distr(x$death_rate_distr)
 }
 
 #' Determine if x is an initialized Coalescent Bayesian Skyline
@@ -43,11 +43,11 @@ is_init_bd_tree_prior <- function(
 #' @return TRUE if x is an initialized Coalescent Bayesian Skyline
 #'   tree prior object
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 is_init_cbs_tree_prior <- function(
   x
 ) {
-  testit::assert(is_cbs_tree_prior(x)) # nolint beautier function
+  testit::assert(beautier::is_cbs_tree_prior(x))
 
   # Yup, is always initialized
   TRUE
@@ -60,11 +60,11 @@ is_init_cbs_tree_prior <- function(
 #' @return TRUE if x is an initialized Coalescent Constant Population
 #'   tree prior object
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 is_init_ccp_tree_prior <- function(
   x
 ) {
-  is_init_distr(x$pop_size_distr) # nolint beautier function
+  beautier::is_init_distr(x$pop_size_distr)
 }
 
 #' Determine if x is an initialized Coalescent Exponential Population
@@ -74,12 +74,13 @@ is_init_ccp_tree_prior <- function(
 #' @return TRUE if x is an initialized Coalescent Exponential Population
 #'   tree prior object
 #' @author Richèl J.C. Bilderbeek
+#' @export
 is_init_cep_tree_prior <- function(
   x
 ) {
-  testit::assert(is_cep_tree_prior(x)) # nolint beautier function
-  is_init_distr(x$pop_size_distr) &&  # nolint beautier function
-  is_init_distr(x$growth_rate_distr)  # nolint beautier function
+  testit::assert(beautier::is_cep_tree_prior(x))
+  beautier::is_init_distr(x$pop_size_distr) &&
+  beautier::is_init_distr(x$growth_rate_distr)
 }
 
 #' Determine if x is an initialized Yule tree_prior object
@@ -87,10 +88,10 @@ is_init_cep_tree_prior <- function(
 #'   initialized Yule tree prior object
 #' @return TRUE if x is an initialized Yule tree_prior object
 #' @author Richèl J.C. Bilderbeek
-#' @noRd
+#' @export
 is_init_yule_tree_prior <- function(
   x
 ) {
-  testit::assert(is_yule_tree_prior(x)) # nolint beautier function
-  is_init_distr(x$birth_rate_distr) # nolint beautier function
+  testit::assert(beautier::is_yule_tree_prior(x))
+  beautier::is_init_distr(x$birth_rate_distr)
 }
